@@ -9,7 +9,6 @@ This module provides creation of new jwt also using basic auth to get the jwt an
 try:
     import jwt
     import typing
-    import traceback
     from functools import wraps
     from base64 import b64decode
     from flask import request, current_app, abort, make_response, jsonify
@@ -84,11 +83,10 @@ class Core():
             return func
 
 class GenJwt(Core):
-    def __init__(self, default_jwt_claims: bool = True, registered_claims_only: bool = True, complete_traceback_genjwt: bool = False) -> None:
+    def __init__(self, default_jwt_claims: bool = True, registered_claims_only: bool = True) -> None:
         self.jwt_fields_attr: dict = None
         self.default_jwt_claims: bool = default_jwt_claims
         self.registered_claims_only: bool = registered_claims_only
-        self.complete_traceback_genjwt: bool = complete_traceback_genjwt
     
     def __validate_registered_claims(self) -> None:
         """
@@ -185,26 +183,15 @@ class GenJwt(Core):
         def func_to_receive(func):
             @wraps(func)
             def wrapper(*args, **kwargs):
-                try:
-                    if self.enc_dec_jwt_callback is None:
-                        self.gen_abort_error("get_decode_jwt_attributes decorator and function to verify password and username is not set", 500)
-                    else:
-                        self.__verify_basic_auth()
-                        jwt_payload = self.__create_jwt_payload()
-                        token = self.__encode_jwt(jwt_payload)
-                        self.verify_user_roles(roles)
+                if self.enc_dec_jwt_callback is None:
+                    self.gen_abort_error("get_decode_jwt_attributes decorator and function to verify password and username is not set", 500)
+                else:
+                    self.__verify_basic_auth()
+                    jwt_payload = self.__create_jwt_payload()
+                    token = self.__encode_jwt(jwt_payload)
+                    self.verify_user_roles(roles)
 
-                    return self.ensure_sync(func)(token, *args, **kwargs)
-                except Exception:
-                    if self.complete_traceback_genjwt:
-                        # This can be used to return traceback using the API for DEV purposes.
-                        error = traceback.format_exc()
-                        self.gen_abort_error(str(error), 500)
-                    else:
-                        # Otherwise this is the default which returns an internal server error to the API
-                        # and prints the traceback to the console.
-                        print(f"The following ERROR occurred in {__file__}: {traceback.format_exc()}")
-                        self.gen_abort_error("Internal server error", 500)
+                return self.ensure_sync(func)(token, *args, **kwargs)
             return wrapper
         if func:
             return func_to_receive(func)
@@ -212,11 +199,10 @@ class GenJwt(Core):
 
 class DecJwt(Core):
     token: dict = None
-    def __init__(self, token_as_attr: bool = False, complete_traceback_decjwt: bool = False) -> None:
+    def __init__(self, token_as_attr: bool = False) -> None:
         self.token_as_attr: bool = token_as_attr
         self.credentials_success_callback: dict = None
         self.get_jwt_claims_to_verify_callback: list = None
-        self.complete_traceback_decjwt: bool = complete_traceback_decjwt
     
     def __decode_jwt(self) -> tuple[str, None]:
         """
@@ -297,27 +283,16 @@ class DecJwt(Core):
         def func_to_receive(func):
             @wraps(func)
             def wrapper(*args, **kwargs):
-                try:
-                    if self.enc_dec_jwt_callback is None:
-                        self.gen_abort_error("get_decode_jwt_attributes decorator and function to verify password and username is not set", 500)
-                    else:
-                        token = self.__decode_jwt()
-                        self.__verify_token(token)
-                        self.verify_user_roles(roles)
-                        self.__authenticate_credentials(token)
-                        self.__set_token_as_attr(token)
+                if self.enc_dec_jwt_callback is None:
+                    self.gen_abort_error("get_decode_jwt_attributes decorator and function to verify password and username is not set", 500)
+                else:
+                    token = self.__decode_jwt()
+                    self.__verify_token(token)
+                    self.verify_user_roles(roles)
+                    self.__authenticate_credentials(token)
+                    self.__set_token_as_attr(token)
 
-                    return self.ensure_sync(func)(*args, **kwargs)
-                except Exception:
-                    error = traceback.format_exc()
-                    if self.complete_traceback_decjwt:
-                        # This can be used to return traceback using the API for DEV purposes.
-                        self.gen_abort_error(str(error), 500)
-                    else:
-                        # Otherwise this is the default which returns an internal server error to the API
-                        # and prints the traceback to the console.
-                        print(f"The following ERROR occurred in {__file__}: {error}")
-                        self.gen_abort_error("Internal server error", 500)
+                return self.ensure_sync(func)(*args, **kwargs)
             return wrapper
         if func:
             return func_to_receive(func)
